// FILENAME:	TeamArena.cs
// 1:57 AM 8/1/99
// AUTHORS:  	Orogogus
//------------------------------------------------------------------------------

//=============  Server settings

$missionName = "Team Arena";

exec("multiplayerStdLib.cs");
exec("DMStdLib.cs");
exec("tarenascoring.cs");

function setDefaultMissionOptions()
{
	$server::TeamPlay = true;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;

   // what can the server admin choose for available teams
   $server::disableTeamRed = false;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = true;
}


//=============  Some default settings for the mission


function onMissionStart()
{
	plutoSounds();
}


function onMissionLoad()
{
   cdAudioCycle("Purge", "Newtech", "SS4", "SS3"); 
}


function setDefaultMissionItems() 
{
	exec("defaultVehicles");
	allowComponent("all", true);
	allowWeapon("all", true);

	allowVehicle(17,FALSE);  //KnightDisrupter
	allowVehicle(8,FALSE);//Disrupter
	allowComponent(875,FALSE);//FieldStabilizer
	allowWeapon(3,TRUE);//Disrupter
}


//=======================


$playersReady = 0;
$totalPlayers = 0;
$teleportersOn = 0;
$blueCount = 0;
$redCount = 0;

//=======================


function player::onAdd( %player )
{
	%player.home = 100;
	%player.lobbyKills = 0;
	%player.lobbyDeaths = 0;
}


function vehicle::onAdd(%vehicle)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicle);
	setVehicleRadarVisible( %vehicle, False );

	%player.home = 100;
	%player.name = getHUDName(%vehicle);
	%player.vehicleId = %vehicle;
	%player.vehicle = getVehicleName(%vehicle);

	$totalPlayers++;

	%team = getTeam(%player);
	%player.color = teamToColor(%team);
	say(%player, 0, "You are in the spawn area.  Please go to the ready room at the end of the hall.");
//	say(%player, 0, "Team " @ %player.color);

}


function vehicle::onDestroyed( %victimVeh, %destroyerVeh )
{
	$totalPlayers--;
	if($totalPlayers < 0)
	{
		$totalPlayers = 0;
	}

	%victim = playerManager::vehicleIdToPlayerNum(%victimVeh);
	%victor = playerManager::vehicleIdToPlayerNum(%destroyerVeh);

	if( %victim.home == 1)
	{
//============= Quick and dirty cut and paste.
		// left over from missionStdLib.cs
		vehicle::onDestroyedLog(%victimVeh, %destroyerVeh);
   
		// this is weird but %destroyer isn't necessarily a vehicle
		%message = getFancyDeathMessage(getHUDName(%victimVeh), getHUDName(%destroyerVeh));
		if(%message != "")
		{
			say( 0, 0, %message);
		}
//=============

		%team = getTeam(%destroyed);
		

		if (%victim.color == "blue")
		{
			$blueCount--;
		}

		if (%victim.color == "red")
		{
			$redCount--;
		}


		if ( ($teleportersOn == 0) && (($blueCount == 0) || ($redCount == 0)) )
		{
			say( everybody, 0, %victim.color @ " loses.");
			say( everybody, 0, "Mission restarts in ten seconds.");
			schedule("missionEndConditionMet();", 30);
		}
	}


	if( %victim.home == 100)
	{
		%victim.lobbyDeaths++;
		%victor.lobbyKills++;
	}

}


//=======================

function Beamer::trigger::onEnter(%this, %vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);
	%team = getTeam(%player);

	if ($teleportersOn == 0)
	{
		say(%player, 0, "Teleporter not activated.  Please step off and wait.");
	}

	if ($teleportersOn == 1)
	{
		randomTransport(%vehicleId, -2500, -2450, 2980, 3000);
		%player.home = 1;

		healObject( %vehicleId, 50000);
		healObject( %vehicleId, 50000);
		reloadObject( %vehicleId, 100);
		healObject( %vehicleId, 50000);

		setVehicleRadarVisible( %vehicle, True );

		if (%player.color == "blue")
		{
			$blueCount++;
			say(everybody, 0, "Teleporting in: "@%player.name@" on blue team.");
		}

		if (%player.color == "red")
		{
			$redCount++;
			say(everybody, 0, "Teleporting in: "@%player.name@" on red team.");
		}
	}
}


function TeleportArea::trigger::onEnter(%this, %vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);
	say(%player, 0, "You have entered the ready room.");
	$playersReady++;

	if ($playersReady < $totalPlayers)
	{
		say(%player, 0, "When all players are ready, the teleporters have been activated for one minute.");
	}

	if (($playersReady == $totalPlayers) && ($teleportersOn != 1))
	{
		say(everybody, 0, "All players ready.  The teleporters will be activated for one minute.");
//		setHudTimer(60, -1, "Teleporters On", 1, %player);
		$teleportersOn = 1;
		schedule("TeleportersOff();", 60);
	}
}

function TeleportersOff()
{
	$teleportersOn = 0;
	say(everybody, 0, "The teleporters have been deactivated.  The game will now end when one team is wiped out.");
}

function TeleportArea::trigger::onLeave(%this, %vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);
	say(%player, 0, "(You have left the teleport area)");
	$playersReady--;
	if($playersReady < 0) 
	{
		$playersReady = 0;
	}
}


//=======================  Functions that I copied wholesale, with perhaps minor edits


function randomTransport( %object, %x1, %y1, %x2, %y2)
{
   // set the position of %object to a randow spot within the space
   // bounded by (x1, y1) and (x2, y2).  The Z coordinate is going to
   // be set to 5 meters above the terrain at the new point.
   
   %x = randomInt(%x1, %x2);
   %y = randomInt(%y1, %y2);
   %z = getTerrainHeight(%x, %y) + 5;

	%playerNum = playerManager::vehicleIdToPlayerNum(%object);
 
   // play a sound at both locations
   playSound(0, IDSFX_TELEPORTER, IDPRF_NEAR, %object);
   playSound(0, IDSFX_TELEPORTER, IDPRF_NEAR, %x, %y, %z);
   
   if(%playerNum != 0)
   {
   	fadeEvent(%playerNum, out, 1.0, 1.0, 1.0, 1.0);
   	schedule(strcat("fadeEvent(", %playerNum, ",in, 1.0, 1.0, 1.0, 1.0);"), 1.2);
   }
   schedule(strcat("setPosition(", %object, ",", %x,",", %y,",", %z,");"), 1.0);   
}


function teamToColor(%team)
{
	if(%team == *IDSTR_TEAM_YELLOW)
	{return "Yellow";}
	if(%team == *IDSTR_TEAM_BLUE)
	{return "Blue";}
	if(%team == *IDSTR_TEAM_RED)
	{return "Red";}
	if(%team == *IDSTR_TEAM_PURPLE)
	{return "Purple";}

	return 0;
}   